requests = [
    {
        'name': 'company',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP'
        }
    },
    {
        'name': 'market-data',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'date': 'Date for which market data is required e.g. 20170208'
        }
    },
    {
        'name': 'market-data-eod',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'company-technicals',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'company-financials',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'company-returns',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'company-movaverage',
        'params': {
                'securityId': 'Security ID of company e.g. NSE:7UP',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    },
    {
        'name': 'currency',
        'params': {
                'country_name': 'Name of country e.g. Tunisia'
        }
    },
    {
        'name': 'currency-rate',
        'params': {
                'curr_code': 'Currency code e.g. TND',
                'base_curr': 'Base currency code e.g. USD',
                'startDate': 'Start date from which you require data e.g. 2017-03-01',
                'endDate': 'End date upto which you require data e.g. 2017-03-31'
        }
    }
]



from distutils.core import setup
setup(
  name = 'qtx',
  packages = ['qtx'],
  version = '0.1',
  description = 'API client for Quantextive AEX Data Platform',
  author = 'Quantextive',
  author_email = 'api@quantextive.com',
  url = 'https://github.com/quantextive/qtx', #github repo
  download_url = 'https://github.com/quantextive/qtx/archive/0.1.tar.gz',
  keywords = ['africa', 'finance', 'quantextive'],
  classifiers = [],
)




import sys
import requests as r
import pandas as pd
from pandas.io.json import json_normalize
import json
import decimal
import apis

base_url = "https://api.quantextive.net"
possible_date_fields = [ 'date', 'entry_date', 'MDEntryDate', 'TradeDate', 'rate_date' ]
possible_time_fields = [ 'MDEntryTime' ]

class JsonEncoder(json.JSONEncoder):
    def default(self, o):
        if isinstance(o, decimal.Decimal):
            if o % 1 > 0:
                return float(o)
            else:
                return int(o)
        return super(JsonEncoder, self).default(o)

class Response(object):

    def __init__(self, response):
    	self.response = response

    def json(self):
    	return self.response

    def data_frame(self):
        df = json_normalize(self.response)
        for dateField in possible_date_fields:
            if dateField in df.columns:
                df[dateField] = pd.to_datetime(df[dateField], infer_datetime_format=True)
                sorted = False
                for timeField in possible_time_fields:
                    if timeField in df.columns:
                        df = df.sort_values([dateField, timeField], ascending=False)
                        sorted = True
                if not sorted:
                    df = df.sort_values(dateField, ascending=False)
        return df

class ApiClient(object):

    def __init__(self, default_headers=None):
    	if default_headers is None:
    		default_headers = {}
        self.default_headers = default_headers

    def get(self, api_key, name, params):
        aggr_headers = {}
        aggr_headers.update(self.default_headers)
        
        if api_key != None and api_key != '':
    	    aggr_headers['x-api-key'] = api_key
        
        if 'x-api-key' not in aggr_headers:
            print >> sys.stderr, "API key is required to make a request."
            raise SystemExit
        
        api_found = False
        api_req = None
        if name != None and name != '':
            for request in apis.requests:
                if request['name'] == name:
                    api_found = True
                    api_req = request
                    break
            if not api_found:
                print >> sys.stderr, "API couldn't be found in the available requests " + name
        else:
            print >> sys.stderr, "Error: api name and its params should be supplied"

        if not api_found:
            raise SystemExit

        for param in api_req['params']:
            if param not in params:
                print >> sys.stderr, "Required param missing: --" + param + ', description: ' + api_req['params'][param]
                raise SystemExit

        
        res = r.get(url='/'.join([base_url, name]), params=params, headers=aggr_headers)
        return Response(res.json())